@@ -8,22 +8,25 @@ const ProgressBar = ({ tot, counter, message, error }) => {
   }
   const progress = tot === 0 ? 0 : Math.floor((counter * 100) / tot);
   return (
-    <div className="status-bar">
-      <Line
-        percent={progress}
-        strokeWidth="2"
-        strokeLinecap="butt"
-        strokeColor={progress === 100 ? '#008000' : '#007bb1'}
-      />
-      {}
-      {tot > 0 ? (
-        <div>
-          {counter}/{tot} ({progress}%)
-        </div>
-      ) : (
-        ''
-      )}
-    </div>
+    <React.Fragment>
+      {message ? <div>{message}</div> : ''}
+      <div className="status-bar">
+        <Line
+          percent={progress}
+          strokeWidth="2"
+          strokeLinecap="butt"
+          strokeColor={progress === 100 ? '#008000' : '#007bb1'}
+        />
+        {}
+        {tot > 0 ? (
+          <div>
+            {counter}/{tot} ({progress}%)
+          </div>
+        ) : (
+          ''
+        )}
+      </div>
+    </React.Fragment>
   );
 };
 
